/* AT&T DSP16, 67 tap FIR Filter      jkf  Oct 14, 1988 */
/*							*/
/*  DSP16/DSP16A 67 tap FIR filter benchmark:	fir67.s	*/
/*  Execution (with I/O) requires 81 cycles/sample	*/
/*							*/
/*    (4.46us per sample; sample rate = 224 KHz @ 55ns).*/
/*    (2.67us per sample; sample rate = 374 KHz @ 33ns).*/
/*							*/
/*  Rom requirements are:				*/
/*		Program		19 words		*/
/*		Coefficients	67 words		*/
/*							*/
/*  Ram requirement is:		67 words		*/
/*							*/

.ram
X66:	65*int	/* Statements between ".ram" and ".endram" are	*/
X1:	int	/* assembler directives used to initialize RAM 	*/
ibuf:	int	/* addresses. They are not DSP16 instructions.	*/
.endram

fir67:		auc=0x2		/* Automatic Q14 product normalization.	*/
		pt=H66		/* Initialize coefficient pointer.	*/
		i=-66		/* Initialize ROM incr. pointer.	*/
		rb=X66		/* Init modulo addr register (begin).	*/
		re=X1		/* Init modulo addr register (end).	*/
		r1=X66		/* Initialize state variable pointer.	*/
		r0=ibuf		/* Set r0 = to RAM address for I/O.	*/
loop:	*r0=pdx0		/* Input data into RAM loc "ibuf."	*/

			/* Perform convolution	*/

	/* 3 stage DAU pipeline is executed as follows:	*/
	/*                               y and x fetch	*/
	/*                   multiply			*/
	/*    accumulate				*/
	/* Multiply and/or accumulate statements are	*/
	/* permitted in an instruction with x,y fetches,*/
	/* but multiply and/or accumulation operations	*/
	/* will be performed on data loaded in the 	*/
	/* previous instruction (user-visible pipeline).*/


		a0=p                y=*r1++    x=*pt++ /* Fetch x(66) & h(66)*/
	do 65 	{
		a0=a0-p    p=x*y    y=*r1++    x=*pt++
		}
		a0=a0-p	   p=x*y    y=*r0      x=*pt++i /* Re-init coef ptr  */
		a0=a0-p    p=x*y    *r1++=y
		a0=a0-p
		pdx1=a0
endl:	goto	loop


/*		Coefficients from h(66) to h(0)		*/

H66:	int	0.000545
	int	0.000000
	int	-0.000641
	int	-0.001046
	int	-0.000876
	int	0.000000
	int	0.001275
	int	0.002184
	int	0.001864
	int	0.000000
	int	-0.002673
	int	-0.004485
	int	-0.003739
	int	0.000000
	int	0.005112
	int	0.008391
	int	0.006859
	int	0.000000
	int	-0.009085
	int	-0.014743
	int	-0.011954
	int	0.000000
	int	0.015755
	int	0.025682
	int	0.021038
	int	0.000000
	int	-0.028989
	int	-0.049177
	int	-0.042713
	int	0.000000
	int	0.073628
	int	0.157832
	int	0.000545
	int	0.000000
	int	-0.000641
	int	-0.001046
	int	-0.000876
	int	0.000000
	int	0.001275
	int	0.002184
	int	0.001864
	int	0.000000
	int	-0.002673
	int	-0.004485
	int	-0.003739
	int	0.000000
	int	0.005112
	int	0.008391
	int	0.006859
	int	0.000000
	int	-0.009085
	int	-0.014743
	int	-0.011954
	int	0.000000
	int	0.015755
	int	0.025682
	int	0.021038
	int	0.000000
	int	-0.028989
	int	-0.049177
	int	-0.042713
	int	0.000000
	int	0.073628
	int	0.157832
	int	0.000000
	int	0.073628
	int	0.157832


