/* AT&T DSP16, 8th order IIR Filter   JKF  Oct 14, 1988 */
/*							*/
/*  DSP16 8th order benchmark IIR filter. 	iir8.s	*/
/*  Implementation is Direct Form II.			*/
/*							*/
/*  Execution requires 46 cycles/sample. 		*/
/*    (2.53us per sample; sample rate = 395 KHz @ 55ns).*/
/*    (1.52us per sample; sample rate = 659 KHz @ 33ns).*/
/*							*/
/*  Rom requirements are:				*/
/*		Program		17 words		*/
/*		Coefficients	20 words		*/
/*							*/
/*  Ram requirement is:		8 words			*/
/*						*/
/*  Implementation is a cascade of 4 SOS's. 	*/
/*  I/O is included in benchmark program.	*/
/*  Inputs (16-bit linear) enter via pdx0.     	*/
/*  Outputs (16-bit linear) are sent to pdx1.	*/
/*  Coefficients were not chosen to 		*/
/*  implement any given filter.			*/
/*						*/
.ram
data:   8*int
.endram

/*    The IIR coding example uses the following       */
/*  DSP16 resources:                                  */
/*                                                    */
/*          a0: input/output for each section               */
/*          r1: state variable pointer                      */
/*          pt: pointer to filter coefficients              */
/*          j, k:   for special compound addressing mode    */
/*                                                          */
/*  This coding example demonstrates the use of compound addressing */
/*  for maintaining the state variable delay line.                  */

iir8:   auc=0x12
        j=-2		/* j and k are used for register 	*/
        k=3		/* in compound addressing (see manual).	*/
loop:   pt=coef		/* pt points to coefficients in ROM.	*/
        r1=data		/* r1 points to tap outputs in RAM.	*/
        a0=pdx0		/* Input sample from parallel port0.	*/
                            y=*r1++     x=*pt++     /* d11 */
                   p=x*y    y=*r1--     x=*pt++	    /* d21 */
do 4    {
        a0=a0-p    p=x*y    y=*r1++     x=*pt++	    /*  n1(n)  */
        a0=a0-p	   p=x*y    *r1zp:y     x=*pt++	    /*  n2(n)  */
        a0=p       p=x*y    y=a0        x=*pt++     /*  n0(n)  */
        a0=a0+p    p=x*y    *r1jk:y     x=*pt++	    /* d1(n+1) */
        a0=a0+p	   p=x*y    y=*r1--     x=*pt++	    /* d2(n+1) */
        }
        pdx1=a0
endl:   goto    loop

coef:		int	-1.3322		/* b11 */
		int	 0.6452		/* b21 */
		int	-0.5558		/* a11 */
		int	 1.0000		/* a21 */
		int	 0.4453		/* a01 */



		int	-1.6308		/* b12 */
		int	 0.6539		/* b22 */
		int	 0.0000		/* a12 */
		int	-1.0000		/* a22 */
		int	 0.1730		/* a02 */



		int	-1.3813		/* b13 */
		int	 0.8997		/* b23 */
		int	-1.1427		/* a13 */
		int	 1.0000		/* a23 */
		int	 0.7621		/* a03 */



		int	-1.9668		/* b14 */
		int	 0.9687		/* b24 */
		int	-1.9997		/* a14 */
		int	 1.0000		/* a24 */
		int	 0.4453		/* a04 */


