/* AT&T DSP16, 8th ord.transpose IIR Fltr  jkf 10/14/88 */
/*							*/
/*  DSP16 8th order transpose benchmark IIR filter. 	*/
/*  Implementation is Direct Form I (Transpose form).	*/
/*		iirt8.s					*/
/*  Execution requires 62 cycles/sample. 		*/
/*    (3.41us per sample; sample rate = 293 KHz @ 55ns).*/
/*    (2.05us per sample; sample rate = 488 KHz @ 33ns).*/
/*							*/
/*  Rom requirements are:				*/
/*		Program		19 words		*/
/*		Coefficients	20 words		*/
/*							*/
/*  Ram requirement is:		8 words			*/
/*						*/
/*  Implementation is a cascade of 4 SOS's. 	*/
/*  I/O is included in benchmark program.	*/
/*  Inputs (16-bit linear) enter via pdx0.     	*/
/*  Outputs (16-bit linear) are sent to pdx1.	*/
/*						*/

/*    The IIR coding example uses the following       */
/*  DSP16 resources:                                  */
/*                                                    */
/*          a0: input for each section                */
/*          a1: ouput for each section                */
/*          r1: state variable pointer                      */
/*          pt: pointer to filter coefficients              */
/*          j:  postmodification register for RAM pointers  */
/*                                                          */
/*  This coding example demonstrates the use of compound addressing */
/*  for maintaining the state variable delay line.                  */

iirt8:  auc=0x2
        j=2		/* j is used as a postmodification reg  */
loop:   pt=B01		/* pt points to coefficients in ROM.	*/
        r1=P01		/* r1 points to tap outputs in RAM.	*/
        a0=pdx0		/* Input sample from parallel port0.	*/

	              y=a0  x=*pt++  /* y=input, x=b01	*/
  do 4 {
	        p=x*y a1=*r1--	     /* p=i*b01, a1=P01	*/
	a1=a1+p       y=*r2 x=*pt++  /* a1=P01+i*b01, y=i, x=b21	*/
	        p=x*y y=a1  x=*pt++  /* p=i*b21, y=v1, x=-a21	*/
	a0=p    p=x*y y=a1  x=*pt++  /* a0=i*b21, p=-v1*a21, y=v1, x=a11*/
	a0=a0+p p=x*y y=*r2 x=*pt++  /* a0=i*b21-v1*a21, p=-v1*a11	*/
	*r1zp:a0		     /* y=i, x=b11	*/
	a0=a0+p p=x*y y=a1  x=*pt++  /* a0=P11-v1*a11,p=i*b11	*/
	a0=a0+p
	*r1++j=a0
	}

	pdx1=a1
endl:	goto loop

B01:	int	0.121147
B21:	int	0.120941
A21:	int	-0.276733
A11:	int	0.834961
B11:	int	0.199661
B02:	int	0.393280
B22:	int	0.393021
A22:	int	-0.578308
A12:	int	0.587860
B12:	int	0.196716
B03:	int	0.927734
B23:	int	0.927673
A23:	int	-0.829651
A13:	int	1.815369
B13:	int	-1.855103
B04:	int	0.631134
B24:	int	0.631042
A24:	int	-0.872253
A14:	int	0.485077
B14:	int	0.029175

.ram
P11:	int
P01:	int
P12:	int
P02:	int
P13:	int
P03:	int
P14:	int
P04:	int
.endram

